#ifndef RECIPIENT_H
#define RECIPIENT_H

#include <QWidget>
#include <QLineEdit>
#include <QPushButton>
#include "phonebook.h"

namespace Ui {
    class Recipient;
}

class Recipient : public QWidget
{
    Q_OBJECT

public:
    explicit Recipient(QWidget *parent = 0);
    ~Recipient();
    QLineEdit* getPhoneNumberField();
    QPushButton *m_btSend;
    bool sendSMS(QString sMessage);


private:
    Ui::Recipient *ui;
    PhoneBook *m_phonebook;

public slots:
     bool addRecipient(const QString &phone, const QString &name);

private slots:
    void displayPhoneBook(QString sText);
    void openPhoneBook();
};

#endif // RECIPIENT_H
